Contributing to Multigit
========================

Contributions is done by Pull Requests.

If you plan to contribute, it's a good idea to read doc/code-organisation.md 

Python code is expected to be type annotated and pass successfully with mypy.

For a pull request to be accepted, it must pass the Continuous Integtration tests. They
run mypy and pytest.


Testing
-------

To run the tests, launch pytest from the main directory.

